/*
	             DO NOT MODIFY THIS HEADER!!!
	-----------------------------------------------------------
	
	Product Information________________________________________
	Title: SQL ConnectionInfo Class
	Description: A class for building SQL connection strings 
	and setting proper pooling settings.
	Author: Adam Smith
	Email: webmaster@codevendor.com
	Website: codevendor.com
	Company: CodeVendor, Inc.
	Date Created: May 15, 2005
	Version: 1.0
	Language: C#
	Copyright: Copyright  2005 CodeVendor, Inc. All Rights 
	Reserved.
	__________________________________________________________
	
	Licensing_________________________________________________
	License: Free to use for both Personal and Commercial use.
	__________________________________________________________
		
	References________________________________________________
	http://msdn.microsoft.com/library/default.asp?url=/library
	/en-us/cpref/html/frlrfSystemDataSqlClientSqlConnection
	ClassTopic.asp
	__________________________________________________________	
	
	Terms and Conditions______________________________________
	THIS CODE IS PROVIDED BY THE COPYRIGHT HOLDERS AND 
	CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
	INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF 
	MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE 
	DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER 
	CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
	INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
	(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
	GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR 
	BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
	LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
	(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
	OF THE USE OF THIS CODE, EVEN IF ADVISED OF THE POSSIBILITY
	OF SUCH DAMAGE.
	___________________________________________________________
	
	                     END OF HEADER
	-----------------------------------------------------------
 */

#region Class References
using System;
using System.ComponentModel;
using System.Text;
#endregion

namespace SqlBi.DtsToSsisPrepare {
    /// <summary>ConnectionInfo class for building and separating SQL connection strings.</summary>
    public class ConnectionInfo : IDisposable {
        #region Enumerations

        /// <summary>An enumeration of Encrypt arguments. True==Yes, False==No</summary>
        public enum EncryptArguments {
            /// <summary>A default value representing null.</summary>
            None,

            /// <summary>SQL Server uses SSL encryption for all data sent between the client and server if the server has a certificate installed.</summary>
            True,

            /// <summary>SQL Server does not use SSL encryption for all data sent between the client and server if the server has a certificate installed.</summary>
            False,

            /// <summary>SQL Server uses SSL encryption for all data sent between the client and server if the server has a certificate installed.</summary>
            Yes,

            /// <summary>SQL Server does not use SSL encryption for all data sent between the client and server if the server has a certificate installed.</summary>
            No
        }


        /// <summary>An enumeration of Integrated Security arguments. True==Yes==SSPI, False==No</summary>
        public enum IntegratedSecurityArguments {
            /// <summary>A default value representing null.</summary>
            None,

            /// <summary>The current Windows account credentials are used for authentication.</summary>
            True,

            /// <summary>User ID and Password must be set in sql connection string.</summary>
            False,

            /// <summary>The current Windows account credentials are used for authentication.</summary>
            Yes,

            /// <summary>User ID and Password must be set in sql connection string.</summary>
            No,

            /// <summary>The current Windows account credentials are used for authentication.</summary>
            SSPI
        }


        /// <summary>An enumeration of Persist Security Info arguments. True==Yes, False==No</summary>
        public enum PersistSecurityInfoArguments {
            /// <summary>A default value representing null.</summary>
            None,

            /// <summary>Security-sensitive information is passed through sql connection string. (Not Recommended)</summary>
            True,

            /// <summary>Security-sensitive information, such as the password, is not returned as part of the connection if the connection is open or has ever been in an open state.</summary>
            False,

            /// <summary>Security-sensitive information is passed through sql connection string. (Not Recommended)</summary>
            Yes,

            /// <summary>Security-sensitive information, such as the password, is not returned as part of the connection if the connection is open or has ever been in an open state.</summary>
            No
        }


        /// <summary>An enumeration of Connection Reset arguments. True==Yes, False==No</summary>
        public enum ConnectionResetArguments {
            /// <summary>A default value representing null.</summary>
            None,

            /// <summary>Resets the database connection being drawn from the pool.</summary>
            True,

            /// <summary>Does not reset the database connection being drawn from the pool.</summary>
            False,

            /// <summary>Resets the database connection being drawn from the pool.</summary>
            Yes,

            /// <summary>Does not reset the database connection being drawn from the pool.</summary>
            No
        }


        /// <summary>An enumeration of Enlist arguments. True==Yes, False==No</summary>
        public enum EnlistArguments {
            /// <summary>A default value representing null.</summary>
            None,

            /// <summary>The pooler automatically enlists the connection in the creation thread's current transaction context.</summary>
            True,

            /// <summary>The pooler does not automatically enlists the connection in the creation thread's current transaction context.</summary>
            False,

            /// <summary>The pooler automatically enlists the connection in the creation thread's current transaction context.</summary>
            Yes,

            /// <summary>The pooler does not automatically enlists the connection in the creation thread's current transaction context.</summary>
            No
        }


        /// <summary>An enumeration of Pooling arguments. True==Yes, False==No</summary>
        public enum PoolingArguments {
            /// <summary>A default value representing null.</summary>
            None,

            /// <summary>The SQLConnection object is drawn from the appropriate pool, or if necessary, is created and added to the appropriate pool.</summary>
            True,

            /// <summary>The SQLConnection object is not pooled.</summary>
            False,

            /// <summary>The SQLConnection object is drawn from the appropriate pool, or if necessary, is created and added to the appropriate pool.</summary>
            Yes,

            /// <summary>The SQLConnection object is not pooled.</summary>
            No
        }


        #endregion

        #region Variables

        private string P_ApplicationName;
        private string P_AttachDBFilename;
        private string P_extendedproperties;
        private string P_InitialFileName;
        private int P_ConnectTimeout;
        private int P_ConnectionTimeout;
        private int P_LocaleIdentifier;
        private string P_CurrentLanguage;
        private string P_DataSource;
        private string P_Server;
        private string P_Address;
        private string P_Addr;
        private string P_NetworkAddress;
        private ConnectionInfo.EncryptArguments P_Encrypt;
        private string P_InitialCatalog;
        private string P_Database;
        private ConnectionInfo.IntegratedSecurityArguments P_IntegratedSecurity;
        private ConnectionInfo.IntegratedSecurityArguments P_Trusted_Connection;
        private string P_NetworkLibrary;
        private string P_Net;
        private long P_PacketSize;
        private string P_Password;
        private string P_Pwd;
        private ConnectionInfo.PersistSecurityInfoArguments P_PersistSecurityInfo;
        private string P_UserID;
        private string P_Uid;
        private string P_WorkstationID;
        private int P_ConnectionLifetime;
        private ConnectionInfo.ConnectionResetArguments P_ConnectionReset;
        private ConnectionInfo.EnlistArguments P_Enlist;
        private int P_MaxPoolSize;
        private int P_MinPoolSize;
        private ConnectionInfo.PoolingArguments P_Pooling;

        #endregion

        #region Properties

        /// <summary>The name of the application, or '.Net SqlClient Data Provider' if no application name is provided.</summary>
        public string ApplicationName { get { return P_ApplicationName; } set { P_ApplicationName = value; } }

        /// <summary>The name of the primary file, including the full path name, of an attachable database. The database name must be specified with the keyword 'database'.</summary>
        public string AttachDBFilename { get { return P_AttachDBFilename; } set { P_AttachDBFilename = value; } }

        /// <summary>The name of the primary file, including the full path name, of an attachable database. The database name must be specified with the keyword 'database'.</summary>
        public string extendedproperties { get { return P_extendedproperties; } set { P_extendedproperties = value; } }

        /// <summary>The name of the primary file, including the full path name, of an attachable database. The database name must be specified with the keyword 'database'.</summary>
        public string InitialFileName { get { return P_InitialFileName; } set { P_InitialFileName = value; } }

        /// <summary>The length of time (in seconds) to wait for a connection to the server before terminating the attempt and generating an error.</summary>
        public int ConnectTimeout { get { return P_ConnectTimeout; } set { P_ConnectTimeout = value; } }

        /// <summary>The length of time (in seconds) to wait for a connection to the server before terminating the attempt and generating an error.</summary>
        public int ConnectionTimeout { get { return P_ConnectionTimeout; } set { P_ConnectionTimeout = value; } }

        /// <summary>SQLOLEDB validates the locale ID and returns an error if the locale ID is not supported or is not installed on the client.</summary>
        public int LocaleIdentifier { get { return P_LocaleIdentifier; } set { P_LocaleIdentifier = value; } }

        /// <summary>The SQL Server Language record name.</summary>
        public string CurrentLanguage { get { return P_CurrentLanguage; } set { P_CurrentLanguage = value; } }

        /// <summary>The name or network address of the instance of SQL Server to which to connect.</summary>
        public string DataSource { get { return P_DataSource; } set { P_DataSource = value; } }

        /// <summary>The name or network address of the instance of SQL Server to which to connect.</summary>
        public string Server { get { return P_Server; } set { P_Server = value; } }

        /// <summary>The name or network address of the instance of SQL Server to which to connect.</summary>
        public string Address { get { return P_Address; } set { P_Address = value; } }

        /// <summary>The name or network address of the instance of SQL Server to which to connect.</summary>
        public string Addr { get { return P_Addr; } set { P_Addr = value; } }

        /// <summary>The name or network address of the instance of SQL Server to which to connect.</summary>
        public string NetworkAddress { get { return P_NetworkAddress; } set { P_NetworkAddress = value; } }

        /// <summary>When true, SQL Server uses SSL encryption for all data sent between the client and server if the server has a certificate installed. Recognized values are true, false, yes, and no.</summary>
        public ConnectionInfo.EncryptArguments Encrypt { get { return P_Encrypt; } set { P_Encrypt = value; } }

        /// <summary>The name of the database.</summary>
        public string InitialCatalog { get { return P_InitialCatalog; } set { P_InitialCatalog = value; } }

        /// <summary>The name of the database.</summary>
        public string Database { get { return P_Database; } set { P_Database = value; } }

        /// <summary>When false, User ID and Password are specified in the connection. When true, the current Windows account credentials are used for authentication. Recognized values are true, false, yes, no, and sspi (strongly recommended), which is equivalent to true.</summary>
        public ConnectionInfo.IntegratedSecurityArguments IntegratedSecurity { get { return P_IntegratedSecurity; } set { P_IntegratedSecurity = value; } }

        /// <summary>When false, User ID and Password are specified in the connection. When true, the current Windows account credentials are used for authentication. Recognized values are true, false, yes, no, and sspi (strongly recommended), which is equivalent to true.</summary>
        public ConnectionInfo.IntegratedSecurityArguments Trusted_Connection { get { return P_Trusted_Connection; } set { P_Trusted_Connection = value; } }

        /// <summary>The network library used to establish a connection to an instance of SQL Server. Supported values include dbnmpntw (Named Pipes), dbmsrpcn (Multiprotocol), dbmsadsn (Apple Talk), dbmsgnet (VIA), dbmslpcn (Shared Memory) and dbmsspxn (IPX/SPX), and dbmssocn (TCP/IP).	The corresponding network DLL must be installed on the system to which you connect. If you do not specify a network and you use a local server (for example, "." or "(local)"), shared memory is used.</summary>
        public string NetworkLibrary { get { return P_NetworkLibrary; } set { P_NetworkLibrary = value; } }

        /// <summary>The network library used to establish a connection to an instance of SQL Server. Supported values include dbnmpntw (Named Pipes), dbmsrpcn (Multiprotocol), dbmsadsn (Apple Talk), dbmsgnet (VIA), dbmslpcn (Shared Memory) and dbmsspxn (IPX/SPX), and dbmssocn (TCP/IP).	The corresponding network DLL must be installed on the system to which you connect. If you do not specify a network and you use a local server (for example, "." or "(local)"), shared memory is used.</summary>
        public string Net { get { return P_Net; } set { P_Net = value; } }

        /// <summary>Size in bytes of the network packets used to communicate with an instance of SQL Server.</summary>
        public long PacketSize { get { return P_PacketSize; } set { P_PacketSize = value; } }

        /// <summary>The password for the SQL Server account logging on (Not recommended. To maintain a high level of security, it is strongly recommended that you use the Integrated Security or Trusted_Connection keyword instead.).</summary>
        public string Password { get { return P_Password; } set { P_Password = value; } }

        /// <summary>The password for the SQL Server account logging on (Not recommended. To maintain a high level of security, it is strongly recommended that you use the Integrated Security or Trusted_Connection keyword instead.).</summary>
        public string Pwd { get { return P_Pwd; } set { P_Pwd = value; } }

        /// <summary>When set to false or no (strongly recommended), security-sensitive information, such as the password, is not returned as part of the connection if the connection is open or has ever been in an open state. Resetting the connection string resets all connection string values including the password. Recognized values are true, false, yes, and no.</summary>
        public ConnectionInfo.PersistSecurityInfoArguments PersistSecurityInfo { get { return P_PersistSecurityInfo; } set { P_PersistSecurityInfo = value; } }

        /// <summary>The SQL Server login account (Not recommended. To maintain a high level of security, it is strongly recommended that you use the Integrated Security or Trusted_Connection keyword instead.).</summary>
        public string UserID { get { return P_UserID; } set { P_UserID = value; } }

        /// <summary>The SQL Server login account (Not recommended. To maintain a high level of security, it is strongly recommended that you use the Integrated Security or Trusted_Connection keyword instead.).</summary>
        public string Uid { get { return P_Uid; } set { P_Uid = value; } }

        /// <summary>The name of the workstation connecting to SQL Server.</summary>
        public string WorkstationID { get { return P_WorkstationID; } set { P_WorkstationID = value; } }

        /// <summary>When a connection is returned to the pool, its creation time is compared with the current time, and the connection is destroyed if that time span (in seconds) exceeds the value specified by Connection Lifetime. This is useful in clustered configurations to force load balancing between a running server and a server just brought online. A value of zero (0) causes pooled connections to have the maximum connection timeout.</summary>
        public int ConnectionLifetime { get { return P_ConnectionLifetime; } set { P_ConnectionLifetime = value; } }

        /// <summary>Determines whether the database connection is reset when being drawn from the pool. For Microsoft SQL Server version 7.0, setting to false avoids making an additional server round trip when obtaining a connection, but you must be aware that the connection state, such as database context, is not being reset.</summary>
        public ConnectionInfo.ConnectionResetArguments ConnectionReset { get { return P_ConnectionReset; } set { P_ConnectionReset = value; } }

        /// <summary>When true, the pooler automatically enlists the connection in the creation thread's current transaction context. Recognized values are true, false, yes, and no.</summary>
        public ConnectionInfo.EnlistArguments Enlist { get { return P_Enlist; } set { P_Enlist = value; } }

        /// <summary>The maximum number of connections allowed in the pool.</summary>
        public int MaxPoolSize { get { return P_MaxPoolSize; } set { P_MaxPoolSize = value; } }

        /// <summary>The minimum number of connections allowed in the pool.</summary>
        public int MinPoolSize { get { return P_MinPoolSize; } set { P_MinPoolSize = value; } }

        /// <summary>When true, the SQLConnection object is drawn from the appropriate pool, or if necessary, is created and added to the appropriate pool. Recognized values are true, false, yes, and no.</summary>
        public ConnectionInfo.PoolingArguments Pooling { get { return P_Pooling; } set { P_Pooling = value; } }

        #endregion

        #region Constructor

        /// <summary>ConnectionInfo constructor.</summary>
        public ConnectionInfo() { Declare(); }

        #endregion

        #region DeConstructor

        /// <summary>ConnectionInfo dispose method.</summary>
        public void Dispose() { GC.SuppressFinalize( this ); }

        /// <summary>DeConstructor for ConnectionInfo.</summary>
        ~ConnectionInfo() { Dispose(); }

        #endregion

        #region Public Methods

        /// <summary>Builds an SQLConnection.ConnectionString from specified ConnectionInfo properties.</summary>
        /// <returns>SQLConnection.ConnectionString</returns>
        public override string ToString() {
            try {
                //Declare Variables------------
                StringBuilder SB = new StringBuilder();
                string F_ApplicationName = string.Empty;
                string F_AttachDBFilename = string.Empty;
                string F_extendedproperties = string.Empty;
                string F_InitialFileName = string.Empty;
                string F_ConnectTimeout = string.Empty;
                string F_ConnectionTimeout = string.Empty;
                string F_LocaleIdentifier = string.Empty;
                string F_CurrentLanguage = string.Empty;
                string F_DataSource = string.Empty;
                string F_Server = string.Empty;
                string F_Address = string.Empty;
                string F_Addr = string.Empty;
                string F_NetworkAddress = string.Empty;
                string F_Encrypt = string.Empty;
                string F_InitialCatalog = string.Empty;
                string F_Database = string.Empty;
                string F_IntegratedSecurity = string.Empty;
                string F_Trusted_Connection = string.Empty;
                string F_NetworkLibrary = string.Empty;
                string F_Net = string.Empty;
                string F_PacketSize = string.Empty;
                string F_Password = string.Empty;
                string F_Pwd = string.Empty;
                string F_PersistSecurityInfo = string.Empty;
                string F_UserID = string.Empty;
                string F_Uid = string.Empty;
                string F_WorkstationID = string.Empty;
                string F_ConnectionLifetime = string.Empty;
                string F_ConnectionReset = string.Empty;
                string F_Enlist = string.Empty;
                string F_MaxPoolSize = string.Empty;
                string F_MinPoolSize = string.Empty;
                string F_Pooling = string.Empty;
                //-----------------------------

                //ApplicationName--------------
                F_ApplicationName = (this.ApplicationName == string.Empty || this.ApplicationName == null) ? string.Empty : "Application Name=" + this.ApplicationName + ";";
                SB.Append( F_ApplicationName );
                //-----------------------------

                //FileName---------------------
                F_AttachDBFilename = (this.AttachDBFilename == string.Empty || this.AttachDBFilename == null) ? string.Empty : "AttachDBFilename=" + this.AttachDBFilename + ";";
                F_extendedproperties = (this.extendedproperties == string.Empty || this.extendedproperties == null) ? string.Empty : "extended properties=" + this.extendedproperties + ";";
                F_InitialFileName = (this.InitialFileName == string.Empty || this.InitialFileName == null) ? string.Empty : "Initial File Name=" + this.InitialFileName + ";";
                if (F_AttachDBFilename != string.Empty) {
                    SB.Append( F_AttachDBFilename );
                }
                else {
                    if (F_extendedproperties != string.Empty) {
                        SB.Append( F_extendedproperties );
                    }
                    else {
                        if (F_InitialFileName != string.Empty) { SB.Append( F_InitialFileName ); }
                    }
                }
                //-----------------------------

                //Connection Timeout-----------
                F_ConnectTimeout = (this.ConnectTimeout == 0) ? string.Empty : "Connect Timeout=" + this.ConnectTimeout.ToString() + ";";
                F_ConnectionTimeout = (this.ConnectionTimeout == 0) ? string.Empty : "Connection Timeout=" + this.ConnectionTimeout.ToString() + ";";
                if (F_ConnectTimeout != string.Empty) {
                    SB.Append( F_ConnectTimeout );
                }
                else {
                    if (F_ConnectionTimeout != string.Empty) { SB.Append( F_ConnectionTimeout ); }
                }
                //-----------------------------

                //Locale Identifier-----------
                F_LocaleIdentifier = (this.LocaleIdentifier == 0) ? string.Empty : "Locale Identifier=" + this.LocaleIdentifier.ToString() + ";";
                if (F_LocaleIdentifier != string.Empty) {
                    SB.Append( F_LocaleIdentifier );
                }
                else {
                    if (F_LocaleIdentifier != string.Empty) { SB.Append( F_LocaleIdentifier ); }
                }
                //-----------------------------

                //Current Language-------------
                F_CurrentLanguage = (this.CurrentLanguage == string.Empty || this.CurrentLanguage == null) ? string.Empty : "Current Language=" + this.CurrentLanguage + ";";
                SB.Append( F_CurrentLanguage );
                //-----------------------------

                //DataSource-------------------
                F_DataSource = (this.DataSource == string.Empty || this.DataSource == null) ? string.Empty : "Data Source=" + this.DataSource + ";";
                F_Server = (this.Server == string.Empty || this.Server == null) ? string.Empty : "Server=" + this.Server + ";";
                F_Address = (this.Address == string.Empty || this.Address == null) ? string.Empty : "Address=" + this.Address + ";";
                F_Addr = (this.Addr == string.Empty || this.Addr == null) ? string.Empty : "Addr=" + this.Addr + ";";
                F_NetworkAddress = (this.NetworkAddress == string.Empty || this.NetworkAddress == null) ? string.Empty : "Network Address=" + this.NetworkAddress + ";";
                if (F_DataSource != string.Empty) {
                    SB.Append( F_DataSource );
                }
                else {
                    if (F_Server != string.Empty) {
                        SB.Append( F_Server );
                    }
                    else {
                        if (F_Address != string.Empty) {
                            SB.Append( F_Address );
                        }
                        else {
                            if (F_Addr != string.Empty) {
                                SB.Append( F_Addr );
                            }
                            else {
                                if (F_NetworkAddress != string.Empty) { SB.Append( F_NetworkAddress ); }
                            }
                        }
                    }
                }
                //-----------------------------

                //Encrypt----------------------
                F_Encrypt = string.Empty;
                if (this.Encrypt == EncryptArguments.None) { F_Encrypt = string.Empty; }
                else {
                    switch (this.Encrypt) {
                        case EncryptArguments.True: F_Encrypt = "Encrypt=true;"; break;
                        case EncryptArguments.False: F_Encrypt = "Encrypt=false;"; break;
                        case EncryptArguments.Yes: F_Encrypt = "Encrypt=yes;"; break;
                        case EncryptArguments.No: F_Encrypt = "Encrypt=no;"; break;
                        default: F_Encrypt = string.Empty; break;
                    }
                }
                SB.Append( F_Encrypt );
                //-----------------------------

                //Catalog----------------------
                F_InitialCatalog = (this.InitialCatalog == string.Empty || this.InitialCatalog == null) ? string.Empty : "Initial Catalog=" + this.InitialCatalog + ";";
                F_Database = (this.Database == string.Empty || this.Database == null) ? string.Empty : "Database=" + this.Database + ";";
                if (F_InitialCatalog != string.Empty) {
                    SB.Append( F_InitialCatalog );
                }
                else {
                    if (F_Database != string.Empty) { SB.Append( F_Database ); }
                }
                //-----------------------------

                //Security---------------------
                F_IntegratedSecurity = string.Empty;
                if (this.IntegratedSecurity == IntegratedSecurityArguments.None) { F_IntegratedSecurity = string.Empty; }
                else {
                    switch (this.IntegratedSecurity) {
                        case IntegratedSecurityArguments.True: F_IntegratedSecurity = "Integrated Security=true;"; break;
                        case IntegratedSecurityArguments.False: F_IntegratedSecurity = "Integrated Security=false;"; break;
                        case IntegratedSecurityArguments.Yes: F_IntegratedSecurity = "Integrated Security=yes;"; break;
                        case IntegratedSecurityArguments.No: F_IntegratedSecurity = "Integrated Security=no;"; break;
                        case IntegratedSecurityArguments.SSPI: F_IntegratedSecurity = "Integrated Security=sspi;"; break;
                        default: F_IntegratedSecurity = string.Empty; break;
                    }
                }
                F_Trusted_Connection = string.Empty;
                if (this.Trusted_Connection == IntegratedSecurityArguments.None) { F_Trusted_Connection = string.Empty; }
                else {
                    switch (this.Trusted_Connection) {
                        case IntegratedSecurityArguments.True: F_Trusted_Connection = "Trusted_Connection=true;"; break;
                        case IntegratedSecurityArguments.False: F_Trusted_Connection = "Trusted_Connection=false;"; break;
                        case IntegratedSecurityArguments.Yes: F_Trusted_Connection = "Trusted_Connection=yes;"; break;
                        case IntegratedSecurityArguments.No: F_Trusted_Connection = "Trusted_Connection=no;"; break;
                        case IntegratedSecurityArguments.SSPI: F_Trusted_Connection = "Trusted_Connection=sspi;"; break;
                        default: F_Trusted_Connection = string.Empty; break;
                    }
                }
                if (F_IntegratedSecurity != string.Empty) {
                    SB.Append( F_IntegratedSecurity );
                }
                else {
                    if (F_Trusted_Connection != string.Empty) { SB.Append( F_Trusted_Connection ); }
                }
                //-----------------------------

                //Network Library--------------
                F_NetworkLibrary = (this.NetworkLibrary == string.Empty || this.NetworkLibrary == null) ? string.Empty : "Network Library=" + this.NetworkLibrary + ";";
                F_Net = (this.Net == string.Empty || this.Net == null) ? string.Empty : "Net=" + this.Net + ";";
                if (F_NetworkLibrary != string.Empty) {
                    SB.Append( F_NetworkLibrary );
                }
                else {
                    if (F_Net != string.Empty) { SB.Append( F_Net ); }
                }
                //-----------------------------

                //Packet Size------------------
                F_PacketSize = (this.PacketSize == 0) ? string.Empty : "Packet Size=" + this.PacketSize.ToString() + ";";
                SB.Append( F_PacketSize );
                //-----------------------------

                //Password---------------------
                F_Password = (this.Password == string.Empty || this.Password == null) ? string.Empty : "Password=" + this.Password + ";";
                F_Pwd = (this.Pwd == string.Empty || this.Pwd == null) ? string.Empty : "Pwd=" + this.Pwd + ";";
                if (F_Password != string.Empty) {
                    SB.Append( F_Password );
                }
                else {
                    if (F_Pwd != string.Empty) { SB.Append( F_Pwd ); }
                }
                //-----------------------------

                //Security Info----------------
                F_PersistSecurityInfo = string.Empty;
                if (this.PersistSecurityInfo == PersistSecurityInfoArguments.None) { F_PersistSecurityInfo = string.Empty; }
                else {
                    switch (this.PersistSecurityInfo) {
                        case PersistSecurityInfoArguments.True: F_PersistSecurityInfo = "Persist Security Info=true;"; break;
                        case PersistSecurityInfoArguments.False: F_PersistSecurityInfo = "Persist Security Info=false;"; break;
                        case PersistSecurityInfoArguments.Yes: F_PersistSecurityInfo = "Persist Security Info=yes;"; break;
                        case PersistSecurityInfoArguments.No: F_PersistSecurityInfo = "Persist Security Info=no;"; break;
                        default: F_PersistSecurityInfo = string.Empty; break;
                    }
                }
                SB.Append( F_PersistSecurityInfo );
                //-----------------------------

                //Username---------------------
                F_UserID = (this.UserID == string.Empty || this.UserID == null) ? string.Empty : "User ID=" + this.UserID + ";";
                F_Uid = (this.Uid == string.Empty || this.Uid == null) ? string.Empty : "Uid=" + this.Uid + ";";
                if (F_UserID != string.Empty) {
                    SB.Append( F_UserID );
                }
                else {
                    if (F_Uid != string.Empty) { SB.Append( F_Uid ); }
                }
                //-----------------------------

                //Workstation ID---------------
                F_WorkstationID = (this.WorkstationID == string.Empty || this.WorkstationID == null) ? string.Empty : "Workstation ID=" + this.WorkstationID + ";";
                SB.Append( F_WorkstationID );
                //-----------------------------

                //Connection Lifetime----------
                F_ConnectionLifetime = (this.ConnectionLifetime == 0) ? string.Empty : "Connection Lifetime=" + this.ConnectionLifetime.ToString() + ";";
                SB.Append( F_ConnectionLifetime );
                //-----------------------------

                //Connection Reset-------------
                F_ConnectionReset = string.Empty;
                if (this.ConnectionReset == ConnectionResetArguments.None) { F_ConnectionReset = string.Empty; }
                else {
                    switch (this.ConnectionReset) {
                        case ConnectionResetArguments.True: F_ConnectionReset = "Connection Reset=true;"; break;
                        case ConnectionResetArguments.False: F_ConnectionReset = "Connection Reset=false;"; break;
                        case ConnectionResetArguments.Yes: F_ConnectionReset = "Connection Reset=yes;"; break;
                        case ConnectionResetArguments.No: F_ConnectionReset = "Connection Reset=no;"; break;
                        default: F_ConnectionReset = string.Empty; break;
                    }
                }
                SB.Append( F_ConnectionReset );
                //-----------------------------

                //Enlist-----------------------
                F_Enlist = string.Empty;
                if (this.Enlist == EnlistArguments.None) { F_Enlist = string.Empty; }
                else {
                    switch (this.Enlist) {
                        case EnlistArguments.True: F_Enlist = "Enlist=true;"; break;
                        case EnlistArguments.False: F_Enlist = "Enlist=false;"; break;
                        case EnlistArguments.Yes: F_Enlist = "Enlist=yes;"; break;
                        case EnlistArguments.No: F_Enlist = "Enlist=no;"; break;
                        default: F_Enlist = string.Empty; break;
                    }
                }
                SB.Append( F_Enlist );
                //------------------------------

                //Max Pool Size-----------------
                F_MaxPoolSize = (this.MaxPoolSize == 0) ? string.Empty : "Max Pool Size=" + this.MaxPoolSize.ToString() + ";";
                SB.Append( F_MaxPoolSize );
                //------------------------------

                //Min Pool Size-----------------
                F_MinPoolSize = (this.MinPoolSize == 0) ? string.Empty : "Min Pool Size=" + this.MinPoolSize.ToString() + ";";
                SB.Append( F_MinPoolSize );
                //------------------------------

                //Pooling-----------------------
                F_Pooling = string.Empty;
                if (this.Pooling == PoolingArguments.None) { F_Pooling = string.Empty; }
                else {
                    switch (this.Pooling) {
                        case PoolingArguments.True: F_Pooling = "Pooling=true;"; break;
                        case PoolingArguments.False: F_Pooling = "Pooling=false;"; break;
                        case PoolingArguments.Yes: F_Pooling = "Pooling=yes;"; break;
                        case PoolingArguments.No: F_Pooling = "Pooling=no;"; break;
                        default: F_Pooling = string.Empty; break;
                    }
                }
                SB.Append( F_Pooling );
                //-----------------------------

                return SB.ToString();
            }
            catch { return string.Empty; }
        }


        /// <summary>Parses an SQLConnection.ConnectionString into ConnectionInfo properties.</summary>
        /// <param name="src">The SQLConnection.ConnectionString to parse.</param>
        public void Parse( string src ) {
            try {
                if (src != null && src != string.Empty) {
                    src = src.Replace( "==", "#Equal#" );
                    string[] BreakDown = src.Split( ';' );

                    for (int i = 0; i < BreakDown.Length; i++) {
                        string[] BreakDownProperties = BreakDown[i].Split( '=' );

                        if (BreakDownProperties.Length == 2) {
                            BreakDownProperties[0] = BreakDownProperties[0].Replace( "#Equal#", "==" );
                            BreakDownProperties[1] = BreakDownProperties[1].Replace( "#Equal#", "==" );

                            if (BreakDownProperties[0].Length != 0 && BreakDownProperties[1].Length != 0) {

                                switch (BreakDownProperties[0].ToUpper().Trim()) {
                                    case "APPLICATION NAME": this.ApplicationName = BreakDownProperties[1]; break;
                                    case "ATTACHDBFILENAME": this.AttachDBFilename = BreakDownProperties[1]; break;
                                    case "EXTENDED PROPERTIES": this.extendedproperties = BreakDownProperties[1]; break;
                                    case "INITIAL FILE NAME": this.InitialFileName = BreakDownProperties[1]; break;
                                    case "CONNECT TIMEOUT": this.ConnectTimeout = int.Parse( BreakDownProperties[1] ); break;
                                    case "CONNECTION TIMEOUT": this.ConnectionTimeout = int.Parse( BreakDownProperties[1] ); break;
                                    case "CURRENT LANGUAGE": this.CurrentLanguage = BreakDownProperties[1]; break;
                                    case "DATA SOURCE": this.DataSource = BreakDownProperties[1]; break;
                                    case "SERVER": this.Server = BreakDownProperties[1]; break;
                                    case "ADDRESS": this.Address = BreakDownProperties[1]; break;
                                    case "ADDR": this.Addr = BreakDownProperties[1]; break;
                                    case "NETWORK ADDRESS": this.NetworkAddress = BreakDownProperties[1]; break;
                                    case "LOCALE IDENTIFIER": this.LocaleIdentifier = int.Parse( BreakDownProperties[1] ); break;

                                    case "ENCRYPT":

                                        switch (BreakDownProperties[1].ToUpper().Trim()) {
                                            case "TRUE": this.Encrypt = EncryptArguments.True; break;
                                            case "FALSE": this.Encrypt = EncryptArguments.False; break;
                                            case "YES": this.Encrypt = EncryptArguments.Yes; break;
                                            case "NO": this.Encrypt = EncryptArguments.No; break;
                                            default: this.Encrypt = EncryptArguments.None; break;
                                        }

                                        break;

                                    case "INITIAL CATALOG": this.InitialCatalog = BreakDownProperties[1]; break;
                                    case "DATABASE": this.Database = BreakDownProperties[1]; break;

                                    case "INTEGRATED SECURITY":

                                        switch (BreakDownProperties[1].ToUpper().Trim()) {
                                            case "TRUE": this.IntegratedSecurity = IntegratedSecurityArguments.True; break;
                                            case "FALSE": this.IntegratedSecurity = IntegratedSecurityArguments.False; break;
                                            case "YES": this.IntegratedSecurity = IntegratedSecurityArguments.Yes; break;
                                            case "NO": this.IntegratedSecurity = IntegratedSecurityArguments.No; break;
                                            case "SSPI": this.IntegratedSecurity = IntegratedSecurityArguments.SSPI; break;
                                            default: this.IntegratedSecurity = IntegratedSecurityArguments.None; break;
                                        }

                                        break;

                                    case "TRUSTED_CONNECTION":

                                        switch (BreakDownProperties[1].ToUpper().Trim()) {
                                            case "TRUE": this.Trusted_Connection = IntegratedSecurityArguments.True; break;
                                            case "FALSE": this.Trusted_Connection = IntegratedSecurityArguments.False; break;
                                            case "YES": this.Trusted_Connection = IntegratedSecurityArguments.Yes; break;
                                            case "NO": this.Trusted_Connection = IntegratedSecurityArguments.No; break;
                                            case "SSPI": this.Trusted_Connection = IntegratedSecurityArguments.SSPI; break;
                                            default: this.Trusted_Connection = IntegratedSecurityArguments.None; break;
                                        }

                                        break;

                                    case "NETWORK LIBRARY": this.NetworkLibrary = BreakDownProperties[1]; break;
                                    case "NET": this.Net = BreakDownProperties[1]; break;
                                    case "PACKET SIZE": this.PacketSize = long.Parse( BreakDownProperties[1] ); break;
                                    case "PASSWORD": this.Password = BreakDownProperties[1]; break;
                                    case "PWD": this.Pwd = BreakDownProperties[1]; break;

                                    case "PERSIST SECURITY INFO":

                                        switch (BreakDownProperties[1].ToUpper().Trim()) {
                                            case "TRUE": this.PersistSecurityInfo = PersistSecurityInfoArguments.True; break;
                                            case "FALSE": this.PersistSecurityInfo = PersistSecurityInfoArguments.False; break;
                                            case "YES": this.PersistSecurityInfo = PersistSecurityInfoArguments.Yes; break;
                                            case "NO": this.PersistSecurityInfo = PersistSecurityInfoArguments.No; break;
                                            default: this.PersistSecurityInfo = PersistSecurityInfoArguments.None; break;
                                        }

                                        break;

                                    case "USER ID": this.UserID = BreakDownProperties[1]; break;
                                    case "UID": this.Uid = BreakDownProperties[1]; break;
                                    case "WORKSTATION ID": this.WorkstationID = BreakDownProperties[1]; break;
                                    case "CONNECTION LIFETIME": this.ConnectionLifetime = int.Parse( BreakDownProperties[1] ); break;

                                    case "CONNECTION RESET":

                                        switch (BreakDownProperties[1].ToUpper().Trim()) {
                                            case "TRUE": this.ConnectionReset = ConnectionResetArguments.True; break;
                                            case "FALSE": this.ConnectionReset = ConnectionResetArguments.False; break;
                                            case "YES": this.ConnectionReset = ConnectionResetArguments.Yes; break;
                                            case "NO": this.ConnectionReset = ConnectionResetArguments.No; break;
                                            default: this.ConnectionReset = ConnectionResetArguments.None; break;
                                        }

                                        break;

                                    case "ENLIST":

                                        switch (BreakDownProperties[1].ToUpper().Trim()) {
                                            case "TRUE": this.Enlist = EnlistArguments.True; break;
                                            case "FALSE": this.Enlist = EnlistArguments.False; break;
                                            case "YES": this.Enlist = EnlistArguments.Yes; break;
                                            case "NO": this.Enlist = EnlistArguments.No; break;
                                            default: this.Enlist = EnlistArguments.None; break;
                                        }

                                        break;

                                    case "MAX POOL SIZE": this.MaxPoolSize = int.Parse( BreakDownProperties[1] ); break;
                                    case "MIN POOL SIZE": this.MinPoolSize = int.Parse( BreakDownProperties[1] ); break;

                                    case "POOLING":

                                        switch (BreakDownProperties[1].ToUpper().Trim()) {
                                            case "TRUE": this.Pooling = PoolingArguments.True; break;
                                            case "FALSE": this.Pooling = PoolingArguments.False; break;
                                            case "YES": this.Pooling = PoolingArguments.Yes; break;
                                            case "NO": this.Pooling = PoolingArguments.No; break;
                                            default: this.Pooling = PoolingArguments.None; break;
                                        }

                                        break;

                                    default: break;
                                }
                            }
                        }
                    }
                }
            }
            catch { }
        }


        #endregion

        #region Private Methods

        /// <summary>Method for declaring variables.</summary>
        private void Declare() {
            P_ApplicationName = string.Empty;
            P_AttachDBFilename = string.Empty;
            P_extendedproperties = string.Empty;
            P_InitialFileName = string.Empty;
            P_ConnectTimeout = 0;
            P_ConnectionTimeout = 0;
            P_CurrentLanguage = string.Empty;
            P_DataSource = string.Empty;
            P_Server = string.Empty;
            P_Address = string.Empty;
            P_Addr = string.Empty;
            P_NetworkAddress = string.Empty;
            P_Encrypt = EncryptArguments.None;
            P_InitialCatalog = string.Empty;
            P_Database = string.Empty;
            P_IntegratedSecurity = IntegratedSecurityArguments.None;
            P_Trusted_Connection = IntegratedSecurityArguments.None;
            P_NetworkLibrary = string.Empty;
            P_Net = string.Empty;
            P_PacketSize = 0;
            P_Password = string.Empty;
            P_Pwd = string.Empty;
            P_PersistSecurityInfo = PersistSecurityInfoArguments.None;
            P_UserID = string.Empty;
            P_Uid = string.Empty;
            P_WorkstationID = string.Empty;
            P_ConnectionLifetime = 0;
            P_ConnectionReset = ConnectionResetArguments.None;
            P_Enlist = EnlistArguments.None;
            P_MaxPoolSize = 0;
            P_MinPoolSize = 0;
            P_Pooling = PoolingArguments.None;
        }


        #endregion
    }
}

